# Load the data
eclsk<-read.table('C:/GRE2016/Data/ECLS_Science.dat', na.string='.')

# Give the variable names
names(eclsk)<-c('id','s_g3','r_g3','m_g3',
                     's_g5','r_g5','m_g5', 
                     's_g8','r_g8','m_g8', 
                     'st_g3','rt_g3','mt_g3', 
                     'st_g5','rt_g5','mt_g5', 
                     'st_g8','rt_g8','mt_g8')

head(eclsk)

library(OpenMx)

summary(eclsk)

################# Configural Invariance Model ################# 
con.acad.omx <- mxModel("Configural Model, Path Specification", type="RAM",
 mxData(observed=eclsk, type="raw"),
 manifestVars=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 latentVars=c('eta_1','eta_2','eta_3'),

# Unique Variances
mxPath(from=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 arrows=2, free=TRUE, values=100, 
 labels=c('th_s3','th_r3','th_m3','th_s5','th_r5','th_m5','th_s8','th_r8','th_m8')),

# Unique Covariances
mxPath(from=c('s_g3','s_g3','s_g5','r_g3','r_g3','r_g5','m_g3','m_g3','m_g5'),
 to=c('s_g5','s_g8','s_g8','r_g5','r_g8','r_g8','m_g5','m_g8','m_g8'),
 arrows=2, free=TRUE, values=50, 
 labels=c('th_s53','th_s83','th_s85','th_r53','th_r83','th_r85','th_m53','th_m83','th_m85')),

# Latent Variable Covariances 
mxPath(from=c('eta_1','eta_2','eta_3'), connect='unique.pairs',
 arrows=2, free=c(FALSE,TRUE,TRUE,TRUE,TRUE,TRUE), values = c(1,0,0,1,0,1), 
 labels=c(NA,'psi_21','psi_31','psi_22','psi_32','psi_33')),

# Factor Loadings 
mxPath(from='eta_1', to=c('s_g3','r_g3','m_g3'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r3','lambda_m3')),

mxPath(from='eta_2', to=c('s_g5','r_g5','m_g5'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r5','lambda_m5')),

mxPath(from='eta_3', to=c('s_g8','r_g8','m_g8'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r8','lambda_m8')),

# Latent Variable Means  
mxPath(from='one', to=c('eta_2','eta_3'),
 arrows=1, free=TRUE, values=0, labels=c('alpha_2','alpha_3')),

# Observed Variable Intercepts
mxPath(from='one', to=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 arrows=1, free=TRUE, values=70, 
 labels=c('tau_s','tau_r3','tau_m3','tau_s','tau_r5','tau_m5','tau_s','tau_r8','tau_m8'))

) # Close Model

con.acad.fit <- mxRun(con.acad.omx)

summary(con.acad.fit)

#free parameters:
#        name matrix   row   col   Estimate   Std.Error
#1   lambda_s      A  s_g3 eta_1  13.266138  0.33707627
#2  lambda_r3      A  r_g3 eta_1  26.297932  0.62614259
#3  lambda_m3      A  m_g3 eta_1  21.596950  0.55171665
#4  lambda_r5      A  r_g5 eta_2  22.735706  0.69611107
#5  lambda_m5      A  m_g5 eta_2  20.058764  0.62951288
#6  lambda_r8      A  r_g8 eta_3  21.650415  0.75128024
#7  lambda_m8      A  m_g8 eta_3  17.249724  0.59126382
#8      th_s3      S  s_g3  s_g3  67.089213  3.52118578
#9      th_r3      S  r_g3  r_g3 180.242148 11.29992187
#10     th_m3      S  m_g3  m_g3 187.485868  9.43845306
#11    th_s53      S  s_g3  s_g5  34.771757  3.03269358
#12     th_s5      S  s_g5  s_g5  63.114306  3.80410036
#13    th_r53      S  r_g3  r_g5  82.711140  8.90076749
#14     th_r5      S  r_g5  r_g5 163.018596 10.38751139
#15    th_m53      S  m_g3  m_g5 123.840225  8.13171518
#16     th_m5      S  m_g5  m_g5 176.553668  9.52366531
#17    th_s83      S  s_g3  s_g8  14.702597  2.91359891
#18    th_s85      S  s_g5  s_g8  18.546371  3.08830558
#19     th_s8      S  s_g8  s_g8  53.637134  4.06265657
#20    th_r83      S  r_g3  r_g8  54.135503  9.08467396
#21    th_r85      S  r_g5  r_g8  60.926247  8.84078367
#22     th_r8      S  r_g8  r_g8 185.070189 12.04484603
#23    th_m83      S  m_g3  m_g8  82.115171  6.89834525
#24    th_m85      S  m_g5  m_g8  91.604163  7.12198118
#25     th_m8      S  m_g8  m_g8 126.323254  7.72357812
#26    psi_21      S eta_1 eta_2   1.034523  0.02103249
#27    psi_22      S eta_2 eta_2   1.160852  0.04601038
#28    psi_31      S eta_1 eta_3   1.050844  0.02901660
#29    psi_32      S eta_2 eta_3   1.176373  0.04765468
#30    psi_33      S eta_3 eta_3   1.330118  0.06924130
#31     tau_s      M     1  s_g3  51.011558  0.40732521
#32    tau_r3      M     1  r_g3 127.256524  0.77190845
#33    tau_m3      M     1  m_g3  99.740272  0.66775122
#34    tau_r5      M     1  r_g5 126.654411  0.99405814
#35    tau_m5      M     1  m_g5 102.899995  0.90673111
#36    tau_r8      M     1  r_g8 116.445072  1.67101838
#37    tau_m8      M     1  m_g8  98.550901  1.31166639
#38   alpha_2      M     1 eta_2   1.040343  0.03274881
#39   alpha_3      M     1 eta_3   2.435505  0.06743254
#
#observed statistics:  10551 
#estimated parameters:  39 
#degrees of freedom:  10512 
#-2 log likelihood:  83836.19 
#number of observations:  2108 
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:      62812.193               83914.19                       NA
#BIC:       3382.655               84134.68                 84010.77
#Some of your fit indices are missing.
#  To get them, fit saturated and independence models, and include them with
#  summary(yourModel, SaturatedLikelihood=..., IndependenceLikelihood=...). 
#timestamp: 2014-10-09 20:38:57 
#wall clock time: 47.42251 secs 
#OpenMx version number: 2.0.0.3751 
#Need help?  See help(mxSummary) 



################# Weak Invariance Model ################# 
weak.acad.omx <- mxModel("Weak Model, Path Specification", type="RAM",
 mxData(observed=eclsk, type="raw"),
 manifestVars=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 latentVars=c('eta_1','eta_2','eta_3'),

# Unique Variances
mxPath(from=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 arrows=2, free=TRUE, values=100, 
 labels=c('th_s3','th_r3','th_m3','th_s5','th_r5','th_m5','th_s8','th_r8','th_m8')),

# Unique Covariances
mxPath(from=c('s_g3','s_g3','s_g5','r_g3','r_g3','r_g5','m_g3','m_g3','m_g5'),
 to=c('s_g5','s_g8','s_g8','r_g5','r_g8','r_g8','m_g5','m_g8','m_g8'),
 arrows=2, free=TRUE, values=50, 
 labels=c('th_s53','th_s83','th_s85','th_r53','th_r83','th_r85','th_m53','th_m83','th_m85')),

# Latent Variable Covariances 
mxPath(from=c('eta_1','eta_2','eta_3'), connect='unique.pairs',
 arrows=2, free=c(FALSE,TRUE,TRUE,TRUE,TRUE,TRUE), values = c(1,0,0,1,0,1), 
 labels=c(NA,'psi_21','psi_31','psi_22','psi_32','psi_33')),

# Factor Loadings 
mxPath(from='eta_1', to=c('s_g3','r_g3','m_g3'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r','lambda_m')),

mxPath(from='eta_2', to=c('s_g5','r_g5','m_g5'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r','lambda_m')),

mxPath(from='eta_3', to=c('s_g8','r_g8','m_g8'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r','lambda_m')),

# Latent Variable Means  
mxPath(from='one', to=c('eta_2','eta_3'),
 arrows=1, free=TRUE, values=0, labels=c('alpha_2','alpha_3')),

# Observed Variable Intercepts
mxPath(from='one', to=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 arrows=1, free=TRUE, values=70, 
 labels=c('tau_s','tau_r3','tau_m3','tau_s','tau_r5','tau_m5','tau_s','tau_r8','tau_m8'))

) # Close Model

weak.acad.fit <- mxRun(weak.acad.omx)

summary(weak.acad.fit)

#free parameters:
#       name matrix   row   col    Estimate   Std.Error
#1  lambda_s      A  s_g3 eta_1  14.1483011  0.32832042
#2  lambda_r      A  r_g3 eta_1  25.4165923  0.58954592
#3  lambda_m      A  m_g3 eta_1  20.8746854  0.52409080
#4     th_s3      S  s_g3  s_g3  63.7886041  3.53690408
#5     th_r3      S  r_g3  r_g3 187.2161929 11.49307833
#6     th_m3      S  m_g3  m_g3 194.6016995  9.56675945
#7    th_s53      S  s_g3  s_g5  33.3572801  3.07757484
#8     th_s5      S  s_g5  s_g5  64.2753633  3.84796763
#9    th_r53      S  r_g3  r_g5  79.0278127  9.18818198
#10    th_r5      S  r_g5  r_g5 153.8852746 10.54950696
#11   th_m53      S  m_g3  m_g5 129.5418752  8.33047002
#12    th_m5      S  m_g5  m_g5 183.2385740  9.74049210
#13   th_s83      S  s_g3  s_g8  14.3472715  3.06079707
#14   th_s85      S  s_g5  s_g8  22.1179181  3.26006481
#15    th_s8      S  s_g8  s_g8  62.0445660  4.18312014
#16   th_r83      S  r_g3  r_g8  52.4498872  9.36336277
#17   th_r85      S  r_g5  r_g8  54.4642276  8.97426802
#18    th_r8      S  r_g8  r_g8 179.5365176 12.06562073
#19   th_m83      S  m_g3  m_g8  82.7247899  7.05580627
#20   th_m85      S  m_g5  m_g8  92.5620626  7.33727038
#21    th_m8      S  m_g8  m_g8 122.7552926  7.87364305
#22   psi_21      S eta_1 eta_2   0.9611961  0.01351792
#23   psi_22      S eta_2 eta_2   1.0001886  0.02639301
#24   psi_31      S eta_1 eta_3   0.9022026  0.01882931
#25   psi_32      S eta_2 eta_3   0.9357896  0.02700469
#26   psi_33      S eta_3 eta_3   0.9788830  0.03620049
#27    tau_s      M     1  s_g3  51.0123194  0.42434108
#28   tau_r3      M     1  r_g3 127.2857514  0.75459874
#29   tau_m3      M     1  m_g3  99.7438845  0.65553987
#30   tau_r5      M     1  r_g5 125.4507071  0.98575367
#31   tau_m5      M     1  m_g5 103.3929840  0.86016433
#32   tau_r8      M     1  r_g8 110.8876683  1.49536984
#33   tau_m8      M     1  m_g8  92.5733255  1.28820514
#34  alpha_2      M     1 eta_2   0.9765502  0.02911057
#35  alpha_3      M     1 eta_3   2.2929787  0.05916126
#
#observed statistics:  10551 
#estimated parameters:  35 
#degrees of freedom:  10516 
#-2 log likelihood:  83917.5 
#number of observations:  2108 
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:      62885.495               83987.50                       NA
#BIC:       3433.343               84185.37                 84074.17
#Some of your fit indices are missing.
#  To get them, fit saturated and independence models, and include them with
#  summary(yourModel, SaturatedLikelihood=..., IndependenceLikelihood=...). 
#timestamp: 2014-10-09 20:42:08 
#wall clock time: 37.21228 secs 
#OpenMx version number: 2.0.0.3751 
#Need help?  See help(mxSummary) 




################# Strong Invariance Model ################# 
strong.acad.omx <- mxModel("Strong Model, Path Specification", type="RAM",
 mxData(observed=eclsk, type="raw"),
 manifestVars=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 latentVars=c('eta_1','eta_2','eta_3'),

# Unique Variances
mxPath(from=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 arrows=2, free=TRUE, values=100, 
 labels=c('th_s3','th_r3','th_m3','th_s5','th_r5','th_m5','th_s8','th_r8','th_m8')),

# Unique Covariances
mxPath(from=c('s_g3','s_g3','s_g5','r_g3','r_g3','r_g5','m_g3','m_g3','m_g5'),
 to=c('s_g5','s_g8','s_g8','r_g5','r_g8','r_g8','m_g5','m_g8','m_g8'),
 arrows=2, free=TRUE, values=50, 
 labels=c('th_s53','th_s83','th_s85','th_r53','th_r83','th_r85','th_m53','th_m83','th_m85')),

# Latent Variable Covariances 
mxPath(from=c('eta_1','eta_2','eta_3'), connect='unique.pairs',
 arrows=2, free=c(FALSE,TRUE,TRUE,TRUE,TRUE,TRUE), values = c(1,0,0,1,0,1), 
 labels=c(NA,'psi_21','psi_31','psi_22','psi_32','psi_33')),

# Factor Loadings 
mxPath(from='eta_1', to=c('s_g3','r_g3','m_g3'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r','lambda_m')),

mxPath(from='eta_2', to=c('s_g5','r_g5','m_g5'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r','lambda_m')),

mxPath(from='eta_3', to=c('s_g8','r_g8','m_g8'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r','lambda_m')),

# Latent Variable Means  
mxPath(from='one', to=c('eta_2','eta_3'),
 arrows=1, free=TRUE, values=0, labels=c('alpha_2','alpha_3')),

# Observed Variable Intercepts
mxPath(from='one', to=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 arrows=1, free=TRUE, values=70, 
 labels=c('tau_s','tau_r','tau_m','tau_s','tau_r','tau_m','tau_s','tau_r','tau_m'))

) # Close Model

strong.acad.fit <- mxRun(strong.acad.omx)

summary(strong.acad.fit)

#free parameters:
#       name matrix   row   col    Estimate   Std.Error
#1  lambda_s      A  s_g3 eta_1  15.0876303  0.32292619
#2  lambda_r      A  r_g3 eta_1  22.7392472  0.52853822
#3  lambda_m      A  m_g3 eta_1  20.8065445  0.47443613
#4     th_s3      S  s_g3  s_g3  58.9956910  4.08395032
#5     th_r3      S  r_g3  r_g3 229.9542178 12.59549652
#6     th_m3      S  m_g3  m_g3 197.1985043 10.39349617
#7    th_s53      S  s_g3  s_g5  29.4824172  3.73668790
#8     th_s5      S  s_g5  s_g5  63.3936866  4.56210304
#9    th_r53      S  r_g3  r_g5 109.0302516 10.56552573
#10    th_r5      S  r_g5  r_g5 181.9710587 11.72150838
#11   th_m53      S  m_g3  m_g5 128.3962703  9.13304665
#12    th_m5      S  m_g5  m_g5 188.2925472 10.65716273
#13   th_s83      S  s_g3  s_g8   7.3951902  4.14821846
#14   th_s85      S  s_g5  s_g8   7.8610771  4.65407201
#15    th_s8      S  s_g8  s_g8  58.2555094  5.25563120
#16   th_r83      S  r_g3  r_g8  73.1605668 11.08980123
#17   th_r85      S  r_g5  r_g8  71.5244816 10.42720156
#18    th_r8      S  r_g8  r_g8 208.3442621 12.91936949
#19   th_m83      S  m_g3  m_g8  85.5138115  8.30292371
#20   th_m85      S  m_g5  m_g8  90.3588896  8.51276110
#21    th_m8      S  m_g8  m_g8 126.7087128  9.08514282
#22   psi_21      S eta_1 eta_2   0.9758449  0.01384562
#23   psi_22      S eta_2 eta_2   1.0250268  0.02740202
#24   psi_31      S eta_1 eta_3   0.9101359  0.01923207
#25   psi_32      S eta_2 eta_3   0.9608223  0.02795726
#26   psi_33      S eta_3 eta_3   0.9903943  0.03701478
#27    tau_s      M     1  s_g3  51.4216742  0.45118160
#28    tau_r      M     1  r_g3 126.3103920  0.70696230
#29    tau_m      M     1  m_g3 100.0348641  0.65809535
#30  alpha_2      M     1 eta_2   1.0319245  0.02569133
#31  alpha_3      M     1 eta_3   1.9717645  0.04635254
#
#observed statistics:  10551 
#estimated parameters:  31 
#degrees of freedom:  10520 
#-2 log likelihood:  84341.42 
#number of observations:  2108 
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:      63301.419               84403.42                       NA
#BIC:       3826.652               84578.68                 84480.19
#Some of your fit indices are missing.
#  To get them, fit saturated and independence models, and include them with
#  summary(yourModel, SaturatedLikelihood=..., IndependenceLikelihood=...). 
#timestamp: 2014-10-09 20:47:14 
#wall clock time: 30.703 secs 
#OpenMx version number: 2.0.0.3751 
#Need help?  See help(mxSummary) 


################# Strict Invariance Model ################# 
strict.acad.omx <- mxModel("Strict Model, Path Specification",
 type="RAM",  mxData(observed=eclsk, type="raw"),
 manifestVars=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 latentVars=c('eta_1','eta_2','eta_3'),

# Unique Variances 
mxPath(from=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 arrows=2, free=TRUE, values=100,
 labels=c('th_s','th_r','th_m','th_s','th_r','th_m','th_s','th_r','th_m')),

# Unique Covariances 
mxPath(from=c('s_g3','s_g3','s_g5','r_g3','r_g3','r_g5','m_g3','m_g3','m_g5'), 
 to=c('s_g5','s_g8','s_g8','r_g5','r_g8','r_g8','m_g5','m_g8','m_g8'),  arrows=2, free=TRUE, values=50,
 labels=c('th_s53','th_s83','th_s85','th_r53','th_r83','th_r85','th_m53','th_m83','th_m85')),

# Latent Variable Covariances  
mxPath(from=c('eta_1','eta_2','eta_3'), connect='unique.pairs', 
 arrows=2, free=c(FALSE,TRUE,TRUE,TRUE,TRUE,TRUE), values = c(1,0,0,1,0,1),
 labels=c(NA,'psi_21','psi_31','psi_22','psi_32','psi_33')),

# Factor Loadings  
mxPath(from='eta_1', to=c('s_g3','r_g3','m_g3'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r','lambda_m')),

mxPath(from='eta_2', to=c('s_g5','r_g5','m_g5'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r','lambda_m')),

mxPath(from='eta_3', to=c('s_g8','r_g8','m_g8'),
 arrows=1, free=TRUE, values=20, labels=c('lambda_s','lambda_r','lambda_m')),

# Latent Variable Means   
mxPath(from='one', to=c('eta_2','eta_3'),
 arrows=1, free=TRUE, values=0, labels=c('alpha_2','alpha_3')),

# Observed Variable Intercepts 
mxPath(from='one', to=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 arrows=1, free=TRUE, values=70,
 labels=c('tau_s','tau_r','tau_m','tau_s','tau_r','tau_m','tau_s','tau_r','tau_m'))

) # Close Model

strict.acad.fit = mxRun(strict.acad.omx)

summary(strict.acad.fit)

#free parameters:
#       name matrix   row   col    Estimate  Std.Error
#1  lambda_s      A  s_g3 eta_1  15.1749088 0.31829496
#2  lambda_r      A  r_g3 eta_1  22.9806572 0.51768575
#3  lambda_m      A  m_g3 eta_1  21.2362864 0.47104498
#4      th_s      S  s_g3  s_g3  60.2698421 2.75251768
#5      th_r      S  r_g3  r_g3 208.7606975 7.91909668
#6      th_m      S  m_g3  m_g3 173.2977095 7.00338013
#7    th_s53      S  s_g3  s_g5  28.8421738 2.94524110
#8    th_r53      S  r_g3  r_g5 112.1324486 8.44106632
#9    th_m53      S  m_g3  m_g5 112.5824844 7.07780122
#10   th_s83      S  s_g3  s_g8   6.5929310 2.98503902
#11   th_s85      S  s_g5  s_g8   5.3481884 2.63275428
#12   th_r83      S  r_g3  r_g8  69.4982349 9.03710638
#13   th_r85      S  r_g5  r_g8  79.1903571 9.34634205
#14   th_m83      S  m_g3  m_g8  93.4654618 7.74374739
#15   th_m85      S  m_g5  m_g8 102.4878349 7.76500982
#16   psi_21      S eta_1 eta_2   0.9679592 0.01338906
#17   psi_22      S eta_2 eta_2   1.0105512 0.02635231
#18   psi_31      S eta_1 eta_3   0.9038030 0.01875611
#19   psi_32      S eta_2 eta_3   0.9492382 0.02705506
#20   psi_33      S eta_3 eta_3   0.9707644 0.03580693
#21    tau_s      M     1  s_g3  51.4331658 0.44774023
#22    tau_r      M     1  r_g3 126.3627211 0.70221039
#23    tau_m      M     1  m_g3 100.1927482 0.65088353
#24  alpha_2      M     1 eta_2   1.0202422 0.02477327
#25  alpha_3      M     1 eta_3   1.9470769 0.04487849
#
#observed statistics:  10551 
#estimated parameters:  25 
#degrees of freedom:  10526 
#-2 log likelihood:  84401.28 
#number of observations:  2108 
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:      63349.282               84451.28                       NA
#BIC:       3840.595               84592.62                 84513.19
#Some of your fit indices are missing.
#  To get them, fit saturated and independence models, and include them with
#  summary(yourModel, SaturatedLikelihood=..., IndependenceLikelihood=...). 
#timestamp: 2014-10-07 22:16:46 
#wall clock time: 22.10421 secs 
#OpenMx version number: 2.0.0.3751 
#Need help?  See help(mxSummary) 

mxStandardizeRAMpaths(strict.acad.fit)

################# Latent Growth with Strict Invariance Model ################# 
lgm.acad.omx <- mxModel("Second Order Latent Basis Growth Model, Path Specification", type="RAM",
 mxData(observed=eclsk, type="raw"),
 manifestVars=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 latentVars=c('eta_1','eta_2','eta_3','xi_1','xi_2'),

# Unique Variances
mxPath(from=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 arrows=2, free=TRUE, values=100, 
 labels=c('th_s','th_r','th_m','th_s','th_r','th_m','th_s','th_r','th_m')),

# Unique Covariances
mxPath(from=c('s_g3','s_g3','s_g5','r_g3','r_g3','r_g5','m_g3','m_g3','m_g5'),
 to=c('s_g5','s_g8','s_g8','r_g5','r_g8','r_g8','m_g5','m_g8','m_g8'),
 arrows=2, free=TRUE, values=50, 
 labels=c('th_s53','th_s83','th_s85','th_r53','th_r83','th_r85','th_m53','th_m83','th_m85')),

# Latent Variable Disturbance Variances
mxPath(from=c('eta_1','eta_2','eta_3'), arrows=2, free=TRUE, values=.2, 
 labels='psi'),

# Factor Loadings 
mxPath(from='eta_1', to=c('s_g3','r_g3','m_g3'),
 arrows=1, free=c(FALSE,TRUE,TRUE), values=15.1749088,
 labels=c(NA,'lambda_r','lambda_m')),

mxPath(from='eta_2', to=c('s_g5','r_g5','m_g5'),
 arrows=1, free=c(FALSE,TRUE,TRUE), values=15.1749088,
 labels=c(NA,'lambda_r','lambda_m')),

mxPath(from='eta_3', to=c('s_g8','r_g8','m_g8'),
 arrows=1, free=c(FALSE,TRUE,TRUE), values=15.1749088,
 labels=c(NA,'lambda_r','lambda_m')),

# Observed Variable Intercepts
mxPath(from='one', to=c('s_g3','r_g3','m_g3','s_g5','r_g5','m_g5','s_g8','r_g8','m_g8'),
 arrows=1, free=TRUE, values=70, 
 labels=c('tau_s','tau_r','tau_m','tau_s','tau_r','tau_m','tau_s','tau_r','tau_m')),

## Second-Order Growth Specification ##

# Factor Loadings 
mxPath(from='xi_1', to=c('eta_1','eta_2','eta_3'),
 arrows=1, free=FALSE, values=1),

mxPath(from='xi_2', to=c('eta_1','eta_2','eta_3'),
 arrows=1, free=c(FALSE,TRUE,FALSE), values=c(0,.5,1), 
 labels=c(NA,'gamma_22',NA)),

# Latent Variable Variances & Covariances
mxPath(from=c('xi_1','xi_2'), connect='unique.pairs',
 arrows=2, free=TRUE, values=c(.8,0,.5), 
 labels=c('phi_11','phi_21','phi_22')),

# Latent Variable Means  
mxPath(from='one', to=c('xi_2'),
 arrows=1, free=TRUE, values=0, labels='kappa_2')

) # Close Model

lgm.acad.fit <- mxRun(lgm.acad.omx)

summary(lgm.acad.fit)

#free parameters:
#       name matrix   row   col     Estimate    Std.Error
#1  lambda_r      A  r_g3 eta_1  22.98897356  0.296771614
#2  lambda_m      A  m_g3 eta_1  21.23548090  0.250448952
#3  gamma_22      A eta_2  xi_2   0.52391537  0.006237537
#4      th_s      S  s_g3  s_g3  60.27110458  4.423763569
#5      th_r      S  r_g3  r_g3 208.60749540 10.791908950
#6      th_m      S  m_g3  m_g3 173.82419834  9.925948880
#7    th_s53      S  s_g3  s_g5  28.70353095  4.524295110
#8    th_r53      S  r_g3  r_g5 113.25278838 11.188649411
#9    th_m53      S  m_g3  m_g5 113.49470209 10.015172838
#10   th_s83      S  s_g3  s_g8   6.80230565  6.341068127
#11   th_s85      S  s_g5  s_g8   5.73944175  6.344437494
#12   th_r83      S  r_g3  r_g8  67.86753635 12.757414077
#13   th_r85      S  r_g5  r_g8  78.02129251 12.907379093
#14   th_m83      S  m_g3  m_g8  92.86851524 10.894410307
#15   th_m85      S  m_g5  m_g8 100.70326575 10.861819735
#16      psi      S eta_1 eta_1   0.02426940  0.004031375
#17   phi_11      S  xi_1  xi_1   0.98255711  0.042414332
#18   phi_21      S  xi_1  xi_2  -0.06073336  0.019537961
#19   phi_22      S  xi_2  xi_2   0.11001589  0.017562896
#20    tau_s      M     1  s_g3  51.42363666  0.451225126
#21    tau_r      M     1  r_g3 126.33967208  0.708471750
#22    tau_m      M     1  m_g3 100.18119852  0.653793246
#23  kappa_2      M     1  xi_2   1.94712088  0.023734060
#
#observed statistics:  10551 
#estimated parameters:  23 
#degrees of freedom:  10528 
#-2 log likelihood:  84407.65 
#number of observations:  2108 
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:      63351.654               84453.65                       NA
#BIC:       3831.659               84583.68                 84510.61
#Some of your fit indices are missing.
#  To get them, fit saturated and independence models, and include them with
#  summary(yourModel, SaturatedLikelihood=..., IndependenceLikelihood=...). 
#timestamp: 2014-10-08 22:37:52 
#wall clock time: 26.50965 secs 
#OpenMx version number: 2.0.0.3751 
#Need help?  See help(mxSummary) 
